@@ -413,6 +413,15 @@ seafile_session_prepare (SeafileSession *session)
             seafile_session_config_get_string(session, KEY_PROXY_PASSWORD);
     }
 
+    int block_size = seafile_session_config_get_int(session, KEY_CDC_AVERAGE_BLOCK_SIZE, NULL);
+    if (block_size > 0)
+        session->cdc_average_block_size = block_size;
+    else
+        session->cdc_average_block_size = 0;
+
+    session->disable_block_hash =
+        seafile_session_config_get_bool (session, KEY_DISABLE_BLOCK_HASH);
+    
     /* Start mq manager earlier, so that we can send notifications
      * when start repo manager. */
     seaf_mq_manager_init (session->mq_mgr);
